bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.get_mask
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.get_mask